"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_1 = require("../../cli");
const ssh_1 = require("../../session/ssh");
exports.command = 'audio';
exports.desc = 'Quickly setup the mic & speaker on your device';
exports.handler = (_) => tslib_1.__awaiter(this, void 0, void 0, function* () {
    const ssh = new ssh_1.SSHService();
    yield ssh.connect()
        .catch(e => {
        cli_1.cli.stream.error(e);
        process.exit();
    });
    let captureDevice;
    try {
        const captureDevices = yield ssh.listCaptureDevices();
        if (captureDevices.length === 1) {
            cli_1.cli.stream.success(`Found only 1 capture device named: ${captureDevices[0].name}`);
            cli_1.cli.stream.println(`We will use this device to capture sound`);
            captureDevice = captureDevices[0];
        }
        else {
            const response = yield cli_1.cli.prompt.promptList('device', `We found ${captureDevices.length} interfaces to record sound.\n  Choose the one you want to use`, captureDevices.map(device => device.name));
            captureDevice = captureDevices.find(device => device.name === response['device']);
        }
    }
    catch (e) {
        cli_1.cli.stream.error('Error fetching audio capture device: ' + e.message);
        cli_1.cli.stream.hint('If the microphone is not connected through USB, you might need to install it yourself. See the manufacturers installation guide');
    }
    if (captureDevice === undefined) {
        cli_1.cli.stream.hint('Using default capture configuration card 1 subdevice 0');
        captureDevice = { name: 'Default', card: 1, subdevice: 0 };
    }
    let outputDevice;
    try {
        const outputDevices = yield ssh.listOuputDevices();
        if (outputDevices.length === 1) {
            cli_1.cli.stream.success(`Found only 1 output device named: ${outputDevices[0].name}`);
            cli_1.cli.stream.println(`We will use this device to output sound`);
            outputDevice = outputDevices[0];
        }
        else {
            const response = yield cli_1.cli.prompt.promptList('device', `We found ${outputDevices.length} interfaces to output sound.\n  Choose the one you want to use as your speaker`, outputDevices.map(device => device.name));
            outputDevice = outputDevices.find(device => device.name === response['device']);
        }
    }
    catch (e) {
        cli_1.cli.stream.error('Error fetching audio output device: ' + e.message);
    }
    if (outputDevice === undefined) {
        cli_1.cli.stream.error(`An output device wasn't found`);
        return;
    }
    try {
        yield ssh.setupAsoundConf(outputDevice, captureDevice);
        cli_1.cli.stream.success('Installed /etc/asound.conf');
    }
    catch (e) {
        cli_1.cli.stream.error('Error installing the microphone asound.conf: ' + e.message);
        ssh.disconnect();
        process.exit();
    }
    cli_1.cli.stream.println('Setting to volume to 90%');
    yield ssh.setVolumeLevel(outputDevice.card, 90)
        .catch(e => cli_1.cli.stream.error('Error setting up the volume: ' + e.message));
    cli_1.cli.stream.loading('Restarting snips-audio-server service');
    yield ssh.relaunchService(ssh_1.SnipsServices.audioServer).catch(_ => { });
    cli_1.cli.stream.done();
    cli_1.cli.stream.hint(chalk_1.default `You can test your microphone & speaker with {blue sam test microphone / speaker}`);
    ssh.disconnect();
});
